==> bee-vue-cli-1.0.1.tgz: package/templates/redux/index.js <==
const fs = require('fs-extra')
const path = require('path')
const chalk = require('chalk')
const shelljs = require('shelljs')
const ora = require('ora')//命令行环境的loading效果


/**
 *
 * @param {*} creater creater类
 * @param {*} params  项目参数，包括ask 后的结果
 * @param {*} helper  工具函数：getPkgVersion,shouldUseYarn,shouldUseCnpm,检测安装工具是否可用
 * @param {*} cb
 */
module.exports = function (creater, params, helper, cb) {
  console.log(params)
  const { projectName, description, template, date, src, css } = params
  const configDirName = 'config'
  const cwd = process.cwd()// 返回node环境的当前文件目录
  const projectPath = path.join(cwd, projectName)  // 项目路径
  const sourceDir = path.join(projectPath, src)    // src路径
  const configDir = path.join(projectPath, configDirName) // config路径
  const buildDir = path.join(projectPath, 'build') // build路径
  const assetsDir = path.join(sourceDir, 'assets')
  const componentsDir = path.join(sourceDir, 'components')
  const pagesDir = path.join(sourceDir, 'pages')
  const pageshomeDir = path.join(sourceDir, 'pages', 'home')
  const pluginsDir = path.join(sourceDir, 'plugins')
  const pluginsmixinDir = path.join(sourceDir, 'plugins', 'mixin')
  const routerDir = path.join(sourceDir, 'router')
  const utilsDir = path.join(sourceDir, 'utils')
  const storeDir = path.join(sourceDir, 'store')
  const storeglobalDir = path.join(sourceDir, 'store','global')
  const stylesDir = path.join(sourceDir, 'styles')
  const staticDir = path.join(projectPath, 'static')
  const version = helper.getPkgVersion() // 过去package版本
  const yarnLockfilePath = path.join('yarn-lockfiles', `${version}-yarn.lock`)
  const shouldUseYarn = helper.shouldUseYarn()
  const useNpmrc = shouldUseYarn === false
  const useYarnLock = shouldUseYarn && fs.existsSync(creater.templatePath(template, yarnLockfilePath))
  let appCSSName
  let pageCSSName
  const styleExtMap = {
    sass: 'scss',
    less: 'less',
    stylus: 'styl',
    none: 'css'
  }
  const currentStyleExt = styleExtMap[css] || 'css' // 当前css预编译语言，默认为css


  // NOTE: 在对应的路径生成文件夹
  fs.mkdirSync(projectPath)
  fs.mkdirSync(sourceDir)
  fs.mkdirSync(configDir)
  fs.mkdirSync(buildDir)
  fs.mkdirSync(assetsDir)
  fs.mkdirSync(componentsDir)
  fs.mkdirSync(pagesDir)
  fs.mkdirSync(pageshomeDir)
  fs.mkdirSync(pluginsDir)
  fs.mkdirSync(pluginsmixinDir)
  fs.mkdirSync(routerDir)
  fs.mkdirSync(utilsDir)
  fs.mkdirSync(storeDir)
  fs.mkdirSync(storeglobalDir)
  fs.mkdirSync(stylesDir)
  fs.mkdirSync(staticDir)


  creater.template(template, 'pkg', path.join(projectPath, 'package.json'), {
    description,
    projectName,
    version,
    css,
  })

  //NOTE: 使用类creater的模板生成方法 生成对应的模板文件

  creater.template(template, 'babelrc', path.join(projectPath, '.babelrc'))
  creater.template(template, 'postcssrc', path.join(projectPath, '.postcssrc.js'))
  creater.template(template, 'gitignore', path.join(projectPath, '.gitignore'))
  creater.template(template, 'editorconfig', path.join(projectPath, '.editorconfig'))
  creater.template(template, 'eslintrc', path.join(projectPath, '.eslintrc.json'))
  creater.template(template, 'indexhtml', path.join(projectPath, 'index.html'), {
    projectName
  })

  creater.template(template, 'mainjs', path.join(sourceDir, 'main.js'), {
    css: currentStyleExt
  })
  creater.template(template, 'appvue', path.join(sourceDir, 'app.vue'), {
    css: currentStyleExt
  })
  switch (css) {
    case 'sass':
      appCSSName = 'app.scss'
      pageCSSName = 'index.scss'
      break
    case 'less':
      appCSSName = 'app.less'
      pageCSSName = 'index.less'
      break
    case 'stylus':
      appCSSName = 'app.styl'
      pageCSSName = 'index.styl'
      break
    default:
      appCSSName = 'app.css'
      pageCSSName = 'index.css'
      break
  }

  //NOTE: 分别在pages和根目录生成对应css类型文件
  creater.template(template, path.join('styles', 'commonless'), path.join(sourceDir,'styles', 'common.less'))
  creater.template(template, path.join('styles', 'resetless'), path.join(sourceDir,'styles', 'reset.css'))
  creater.template(template, path.join(configDirName, 'index'), path.join(configDir, 'index.js'), {
    date,
    projectName
  })
  creater.template(template, path.join(configDirName, 'dev'), path.join(configDir, 'dev.env.js'))
  creater.template(template, path.join(configDirName, 'prod'), path.join(configDir, 'prod.env.js'))

  creater.template(template, path.join('components', '404vue'), path.join(sourceDir,'components', '404.vue'))
  creater.template(template, path.join('components', 'helloworldvue'), path.join(sourceDir,'components', 'HelloWorld.vue'))
  creater.template(template, path.join('components', 'indexjs'), path.join(sourceDir,'components', 'index.js'))

  creater.template(template, path.join('pages', 'homeindexvue'), path.join(sourceDir, 'pages','home','index.vue'))

  creater.template(template, path.join('plugins', 'apijs'), path.join(sourceDir, 'plugins','api.js'))
  creater.template(template, path.join('plugins', 'indexjs'), path.join(sourceDir, 'plugins','index.js'))
  creater.template(template, path.join('plugins', 'mixinindexjs'), path.join(sourceDir, 'plugins','mixin','index.js'))

  creater.template(template, path.join('router', 'indexjs'), path.join(sourceDir, 'router','index.js'))

  creater.template(template, path.join('store', 'indexjs'), path.join(sourceDir, 'store','index.js'))
  creater.template(template, path.join('store', 'global', 'actionsjs'), path.join(sourceDir, 'store', 'global','actions.js'))
  creater.template(template, path.join('store', 'global', 'gettersjs'), path.join(sourceDir, 'store', 'global','getters.js'))
  creater.template(template, path.join('store', 'global', 'indexjs'), path.join(sourceDir, 'store', 'global','index.js'))
  creater.template(template, path.join('store', 'global', 'mutationsjs'), path.join(sourceDir, 'store', 'global','mutations.js'))
  creater.template(template, path.join('store', 'global', 'mutationstypesjs'), path.join(sourceDir, 'store', 'global','mutations_types.js'))
  creater.template(template, path.join('store', 'global', 'statejs'), path.join(sourceDir, 'store', 'global','state.js'))

  // NOTE: 生成对应的二级文件夹文件
  creater.template(template, path.join('build', 'baseconfjs'), path.join(projectPath, 'build','webpack.base.conf.js'))
  creater.template(template, path.join('build', 'buildjs'), path.join(projectPath, 'build','build.js'))
  creater.template(template, path.join('build', 'checkversionjs'), path.join(projectPath, 'build','check-versions.js'))
  creater.template(template, path.join('build', 'devconfjs'), path.join(projectPath, 'build','webpack.dev.conf.js'))
  creater.template(template, path.join('build', 'prodconfjs'), path.join(projectPath, 'build','webpack.prod.conf.js'))
  creater.template(template, path.join('build', 'utilsjs'), path.join(projectPath, 'build','utils.js'))
  creater.template(template, path.join('build', 'vueloaderconfjs'), path.join(projectPath, 'build','vue-loader.conf.js'))

  creater.template(template, path.join('utils', 'remjs'), path.join(sourceDir, 'utils','rem.js'))
  creater.template(template, path.join('utils', 'requestjs'), path.join(sourceDir, 'utils','request.js'))
  creater.template(template, path.join('utils', 'toolsjs'), path.join(sourceDir, 'utils','tools.js'))

  if (useNpmrc) creater.template(template, 'npmrc', path.join(projectPath, '.npmrc'))
  if (useYarnLock) creater.template(template, yarnLockfilePath, path.join(projectPath, 'yarn.lock'))
  creater.fs.commit(() => {
    console.log()
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建项目: ${chalk.grey.bold(projectName)}`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建配置目录: ${projectName}/${configDirName}`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建源码目录: ${projectName}/${src}`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建页面目录: ${projectName}/${src}/pages`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建 actions 目录: ${projectName}/${src}/actions`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建 constants 目录: ${projectName}/${src}/constants`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建 reducers 目录: ${projectName}/${src}/reducers`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建 store 目录: ${projectName}/${src}/store`)}`)

    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建页面 JS 文件: ${projectName}/${src}/pages/index/index.js`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建 action counter JS 文件: ${projectName}/${src}/actions/counter.js`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建 constant counter JS 文件: ${projectName}/${src}/constants/counter.js`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建 reducer counter JS 文件: ${projectName}/${src}/reducers/counter.js`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建 reducer 入口 JS 文件: ${projectName}/${src}/reducers/index.js`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建 store JS 文件: ${projectName}/${src}/store/index.js`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建页面 ${currentStyleExt.toLocaleUpperCase()} 文件: ${projectName}/${src}/pages/index/${pageCSSName}`)}`)

    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建文件: ${projectName}/${src}/app.js`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建文件: ${projectName}/${src}/${appCSSName}`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建文件: ${projectName}/${src}/index.html`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建文件: ${projectName}/${configDirName}/index.js`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建文件: ${projectName}/${configDirName}/dev.js`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建文件: ${projectName}/${configDirName}/prod.js`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建文件: ${projectName}/.editorconfig`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建文件: ${projectName}/.gitignore`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建文件: ${projectName}/package.json`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建文件: ${projectName}/.eslintrc`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建文件: ${projectName}/project.config.json`)}`)
    if (useNpmrc) console.log(`${chalk.green('✔ ')}${chalk.grey(`创建文件: ${projectName}/.npmrc`)}`)
    if (useYarnLock) console.log(`${chalk.green('✔ ')}${chalk.grey(`创建文件: ${projectName}/yarn.lock`)}`)
    console.log()
    const gitInitSpinner = ora(`cd ${chalk.cyan.bold(projectName)}, 执行 ${chalk.cyan.bold('git init')}`).start()
    process.chdir(projectName)
    const gitInit = shelljs.exec('git init', { silent: true })
    if (gitInit.code === 0) {
      gitInitSpinner.color = 'green'
      gitInitSpinner.succeed(gitInit.stdout)
    } else {
      gitInitSpinner.color = 'red'
      gitInitSpinner.fail(gitInit.stderr)
    }
    // install
    let command
    if (shouldUseYarn) {
      command = 'yarn install'
    } else if (helper.shouldUseCnpm()) {
      command = 'cnpm install'
    } else {
      command = 'npm install'
    }
    const installSpinner = ora(`执行安装项目依赖 ${chalk.cyan.bold(command)}, 需要一会儿...`).start()
    const install = shelljs.exec(command, { silent: true })
    if (install.code === 0) {
      installSpinner.color = 'green'
      installSpinner.succeed('安装成功')
      console.log(`${install.stderr}${install.stdout}`)
    } else {
      installSpinner.color = 'red'
      installSpinner.fail(chalk.red('安装项目依赖失败，请自行重新安装！'))
      console.log(`${install.stderr}${install.stdout}`)
    }
    console.log(chalk.green(`创建项目 ${chalk.green.bold(projectName)} 成功！`))
    console.log(chalk.green(`请进入项目目录 ${chalk.green.bold(projectName)} 开始工作吧！😝`))
    if (typeof cb === 'function') {
      cb()
    }
  })
}

==> bee-vue-cli-1.0.6.tgz: package/templates/redux/index.js <==
const fs = require('fs-extra')
const path = require('path')
const chalk = require('chalk')
const shelljs = require('shelljs')
const ora = require('ora')//命令行环境的loading效果


/**
 *
 * @param {*} creater creater类
 * @param {*} params  项目参数，包括ask 后的结果
 * @param {*} helper  工具函数：getPkgVersion,shouldUseYarn,shouldUseCnpm,检测安装工具是否可用
 * @param {*} cb
 */
module.exports = function (creater, params, helper, cb) {
  console.log(params)
  const { projectName, description, template, date, src, css } = params
  const configDirName = 'config'
  const cwd = process.cwd()// 返回node环境的当前文件目录
  const projectPath = path.join(cwd, projectName)  // 项目路径
  const sourceDir = path.join(projectPath, src)    // src路径
  const configDir = path.join(projectPath, configDirName) // config路径
  const buildDir = path.join(projectPath, 'build') // build路径
  const assetsDir = path.join(sourceDir, 'assets')
  const componentsDir = path.join(sourceDir, 'components')
  const pagesDir = path.join(sourceDir, 'pages')
  const pageshomeDir = path.join(sourceDir, 'pages', 'home')
  const pluginsDir = path.join(sourceDir, 'plugins')
  const pluginsmixinDir = path.join(sourceDir, 'plugins', 'mixin')
  const routerDir = path.join(sourceDir, 'router')
  const utilsDir = path.join(sourceDir, 'utils')
  const storeDir = path.join(sourceDir, 'store')
  const storeglobalDir = path.join(sourceDir, 'store','global')
  const stylesDir = path.join(sourceDir, 'styles')
  const staticDir = path.join(projectPath, 'static')
  const version = helper.getPkgVersion() // 过去package版本
  const yarnLockfilePath = path.join('yarn-lockfiles', `${version}-yarn.lock`)
  const shouldUseYarn = helper.shouldUseYarn()
  const useNpmrc = shouldUseYarn === false
  const useYarnLock = shouldUseYarn && fs.existsSync(creater.templatePath(template, yarnLockfilePath))
  let appCSSName
  let pageCSSName
  const styleExtMap = {
    sass: 'scss',
    less: 'less',
    stylus: 'styl',
    none: 'css'
  }
  const currentStyleExt = styleExtMap[css] || 'css' // 当前css预编译语言，默认为css


  // NOTE: 在对应的路径生成文件夹
  fs.mkdirSync(projectPath)
  fs.mkdirSync(sourceDir)
  fs.mkdirSync(configDir)
  fs.mkdirSync(buildDir)
  fs.mkdirSync(assetsDir)
  fs.mkdirSync(componentsDir)
  fs.mkdirSync(pagesDir)
  fs.mkdirSync(pageshomeDir)
  fs.mkdirSync(pluginsDir)
  fs.mkdirSync(pluginsmixinDir)
  fs.mkdirSync(routerDir)
  fs.mkdirSync(utilsDir)
  fs.mkdirSync(storeDir)
  fs.mkdirSync(storeglobalDir)
  fs.mkdirSync(stylesDir)
  fs.mkdirSync(staticDir)


  creater.template(template, 'pkg', path.join(projectPath, 'package.json'), {
    description,
    projectName,
    version,
    css,
  })

  //NOTE: 使用类creater的模板生成方法 生成对应的模板文件

  creater.template(template, 'babelrc', path.join(projectPath, '.babelrc'))
  creater.template(template, 'postcssrc', path.join(projectPath, '.postcssrc.js'))
  creater.template(template, 'gitignore', path.join(projectPath, '.gitignore'))
  creater.template(template, 'editorconfig', path.join(projectPath, '.editorconfig'))
  creater.template(template, 'eslintrc', path.join(projectPath, '.eslintrc.json'))
  creater.template(template, 'indexhtml', path.join(projectPath, 'index.html'), {
    projectName
  })

  creater.template(template, 'mainjs', path.join(sourceDir, 'main.js'), {
    css: currentStyleExt
  })
  creater.template(template, 'appvue', path.join(sourceDir, 'app.vue'), {
    css: currentStyleExt
  })
  switch (css) {
    case 'sass':
      appCSSName = 'app.scss'
      pageCSSName = 'index.scss'
      break
    case 'less':
      appCSSName = 'app.less'
      pageCSSName = 'index.less'
      break
    case 'stylus':
      appCSSName = 'app.styl'
      pageCSSName = 'index.styl'
      break
    default:
      appCSSName = 'app.css'
      pageCSSName = 'index.css'
      break
  }

  //NOTE: 分别在pages和根目录生成对应css类型文件
  creater.template(template, path.join('styles', 'commonless'), path.join(sourceDir,'styles', 'common.less'))
  creater.template(template, path.join('styles', 'resetless'), path.join(sourceDir,'styles', 'reset.css'))
  creater.template(template, path.join(configDirName, 'index'), path.join(configDir, 'index.js'), {
    date,
    projectName
  })
  creater.template(template, path.join(configDirName, 'dev'), path.join(configDir, 'dev.env.js'))
  creater.template(template, path.join(configDirName, 'prod'), path.join(configDir, 'prod.env.js'))

  creater.template(template, path.join('components', '404vue'), path.join(sourceDir,'components', '404.vue'))
  creater.template(template, path.join('components', 'helloworldvue'), path.join(sourceDir,'components', 'HelloWorld.vue'))
  creater.template(template, path.join('components', 'indexjs'), path.join(sourceDir,'components', 'index.js'))

  creater.template(template, path.join('pages', 'homeindexvue'), path.join(sourceDir, 'pages','home','index.vue'))

  creater.template(template, path.join('plugins', 'apijs'), path.join(sourceDir, 'plugins','api.js'))
  creater.template(template, path.join('plugins', 'indexjs'), path.join(sourceDir, 'plugins','index.js'))
  creater.template(template, path.join('plugins', 'mixinindexjs'), path.join(sourceDir, 'plugins','mixin','index.js'))

  creater.template(template, path.join('router', 'indexjs'), path.join(sourceDir, 'router','index.js'))

  creater.template(template, path.join('store', 'indexjs'), path.join(sourceDir, 'store','index.js'))
  creater.template(template, path.join('store', 'global', 'actionsjs'), path.join(sourceDir, 'store', 'global','actions.js'))
  creater.template(template, path.join('store', 'global', 'gettersjs'), path.join(sourceDir, 'store', 'global','getters.js'))
  creater.template(template, path.join('store', 'global', 'indexjs'), path.join(sourceDir, 'store', 'global','index.js'))
  creater.template(template, path.join('store', 'global', 'mutationsjs'), path.join(sourceDir, 'store', 'global','mutations.js'))
  creater.template(template, path.join('store', 'global', 'mutationstypesjs'), path.join(sourceDir, 'store', 'global','mutations_types.js'))
  creater.template(template, path.join('store', 'global', 'statejs'), path.join(sourceDir, 'store', 'global','state.js'))

  // NOTE: 生成对应的二级文件夹文件
  creater.template(template, path.join('build', 'baseconfjs'), path.join(projectPath, 'build','webpack.base.conf.js'))
  creater.template(template, path.join('build', 'buildjs'), path.join(projectPath, 'build','build.js'))
  creater.template(template, path.join('build', 'checkversionjs'), path.join(projectPath, 'build','check-versions.js'))
  creater.template(template, path.join('build', 'devconfjs'), path.join(projectPath, 'build','webpack.dev.conf.js'))
  creater.template(template, path.join('build', 'prodconfjs'), path.join(projectPath, 'build','webpack.prod.conf.js'))
  creater.template(template, path.join('build', 'utilsjs'), path.join(projectPath, 'build','utils.js'))
  creater.template(template, path.join('build', 'vueloaderconfjs'), path.join(projectPath, 'build','vue-loader.conf.js'))

  creater.template(template, path.join('utils', 'remjs'), path.join(sourceDir, 'utils','rem.js'))
  creater.template(template, path.join('utils', 'requestjs'), path.join(sourceDir, 'utils','request.js'))
  creater.template(template, path.join('utils', 'toolsjs'), path.join(sourceDir, 'utils','tools.js'))

  if (useNpmrc) creater.template(template, 'npmrc', path.join(projectPath, '.npmrc'))
  if (useYarnLock) creater.template(template, yarnLockfilePath, path.join(projectPath, 'yarn.lock'))
  creater.fs.commit(() => {
    console.log()
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建项目: ${chalk.grey.bold(projectName)}`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建配置目录: ${projectName}/${configDirName}`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建源码目录: ${projectName}/${src}`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建页面目录: ${projectName}/${src}/pages`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建 assets 目录: ${projectName}/${src}/assets`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建 build 目录: ${projectName}/${src}/build`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建 components 目录: ${projectName}/${src}/components`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建 router 目录: ${projectName}/${src}/router`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建 store 目录: ${projectName}/${src}/store`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建 styles 目录: ${projectName}/${src}/styles`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建 uitls 目录: ${projectName}/${src}/uitls`)}`)


    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建页面 JS 文件: ${projectName}/${src}/main.js`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建页面 App Vue 文件: ${projectName}/${src}/app.vue`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建 styles common css 文件: ${projectName}/${src}/styles/common.less`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建 styles reset css 文件: ${projectName}/${src}/styles/reset.css`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建 components 404 vue 文件: ${projectName}/${src}/components/404.vue`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建 components HelloWorld vue 文件: ${projectName}/${src}/components/HelloWorld.vue`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建 components index JS 文件: ${projectName}/${src}/components/index.js`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建 router 入口 JS 文件: ${projectName}/${src}/router/index.js`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建 store 入口 JS 文件: ${projectName}/${src}/store/index.js`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建 plugins 入口 JS 文件: ${projectName}/${src}/plugins/index.js`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建 plugins Api 文件: ${projectName}/${src}/plugins/api.js`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建 plugins mixin JS 文件: ${projectName}/${src}/plugins/mixin/index.js`)}`)


    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建文件: ${projectName}/${src}/${appCSSName}`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建文件: ${projectName}/${src}/index.html`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建文件: ${projectName}/${configDirName}/index.js`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建文件: ${projectName}/${configDirName}/dev.evn.js`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建文件: ${projectName}/${configDirName}/prod.evn.js`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建文件: ${projectName}/.editorconfig`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建文件: ${projectName}/.gitignore`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建文件: ${projectName}/package.json`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建文件: ${projectName}/.eslintrc`)}`)
    console.log(`${chalk.green('✔ ')}${chalk.grey(`创建文件: ${projectName}/.posstcssrc`)}`)
    if (useNpmrc) console.log(`${chalk.green('✔ ')}${chalk.grey(`创建文件: ${projectName}/.npmrc`)}`)
    if (useYarnLock) console.log(`${chalk.green('✔ ')}${chalk.grey(`创建文件: ${projectName}/yarn.lock`)}`)
    console.log()
    const gitInitSpinner = ora(`cd ${chalk.cyan.bold(projectName)}, 执行 ${chalk.cyan.bold('git init')}`).start()
    process.chdir(projectName)
    const gitInit = shelljs.exec('git init', { silent: true })
    if (gitInit.code === 0) {
      gitInitSpinner.color = 'green'
      gitInitSpinner.succeed(gitInit.stdout)
    } else {
      gitInitSpinner.color = 'red'
      gitInitSpinner.fail(gitInit.stderr)
    }
    // install
    let command
    if (shouldUseYarn) {
      command = 'yarn install'
    } else if (helper.shouldUseCnpm()) {
      command = 'cnpm install'
    } else {
      command = 'npm install'
    }
    const installSpinner = ora(`执行安装项目依赖 ${chalk.cyan.bold(command)}, 需要一会儿...`).start()
    const install = shelljs.exec(command, { silent: true })
    if (install.code === 0) {
      installSpinner.color = 'green'
      installSpinner.succeed('安装成功')
      console.log(`${install.stderr}${install.stdout}`)
    } else {
      installSpinner.color = 'red'
      installSpinner.fail(chalk.red('安装项目依赖失败，请自行重新安装！'))
      console.log(`${install.stderr}${install.stdout}`)
    }
    console.log(chalk.green(`创建项目 ${chalk.green.bold(projectName)} 成功！`))
    console.log(chalk.green(`请进入项目目录 ${chalk.green.bold(projectName)} 开始工作吧！😝`))
    console.log(chalk.green(`cd ${chalk.green.bold(projectName)}`))
    console.log(chalk.green(`npm run dev`))
    if (typeof cb === 'function') {
      cb()
    }
  })
}
